<?php

namespace Drupal\editoria11y\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Component\Utility\Xss;

/**
 * Class Editoria11ySettings.
 */
class Editoria11ySettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'editoria11y_form_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'editoria11y.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('editoria11y.settings');
    $form['setup'] = array(
      '#type' => 'fieldset',
      '#title' => t('Scanning'),
    );
    $form['setup']['text'] = array(
      '#markup' => '<p>If things stop working, please empty these fields to check the defaults before <a href="https://www.drupal.org/project/issues/editoria11y?categories=All">submitting an issue</a>. Invalid or conflicting selectors can affect performance or prevent scanning.</p>',
    );
    $form['setup']['content_root'] = [
      '#title' => $this->t("Only check content in this container"),
      '#type' => 'textfield',
      '#placeholder' => 'main',
      '#description' => $this->t('Provide a <a href="https://developer.mozilla.org/en-US/docs/Learn/CSS/Building_blocks/Selectors">selector</a> for one element that wraps around all the content you want scanned, e.g. <code>#my-theme-content-area</code> for a specific section or <code>body</code> for the whole page.'),
      '#default_value' => $config->get('content_root'),
    ];
    $form['setup']['ignore_containers'] = [
      '#title' => $this->t("Ignore these elements"),
      '#type' => 'textfield',
      '#placeholder' => '#toolbar-administration, .contextual-region > nav, .search-results',
      '#description' => $this->t('Provide a comma-separated list of selectors, such as <code>.my-embedded-feed, #my-social-link-block</code>'),
      '#default_value' => $config->get('ignore_containers'),
    ];
    $form['setup']['no_load'] = [
      '#title' => $this->t("Do not check anything if these elements are present"),
      '#type' => 'textfield',
      '#placeholder' => '#quickedit-entity-toolbar, #layout-builder',
      '#description' => $this->t('Editoria11y should never run while content is being edited. <br>If it does not detect an active editing tool and disable itself, provide a comma-separated list of selectors it should watch for, and <a href="https://www.drupal.org/project/issues/editoria11y?categories=All">submit an issue</a> if the conflict is with a common module.<br>Note that this can also be used to flag whole pages you want ignored (<code>.front, .page-with-no-editable-content</code>).'),
      '#default_value' => $config->get('no_load'),
    ];
    $form['results'] = array(
      '#type' => 'fieldset',
      '#title' => t('Testing'),
    );
    $form['results']['assertiveness'] = [
      '#title' => $this->t("Automatic alert highlighting"),
      '#type' => 'radios',
      '#options' => array(
        'smart' => $this->t('When nodes are created or changed'),
        'assertive' => $this->t('Always'),
        'polite' => $this->t('Never')
      ),
      '#description' => $this->t('"Always" is not recommended for sites with multiple editors.'),
      '#default_value' => $config->get('assertiveness'),
    ];
    $form['results']['allow_overflow'] = [
      '#title' => $this->t("Force these containers to allow overflow when tips are open"),
      '#type' => 'textfield',
      '#description' => $this->t('Elements set to overflow:hidden can truncate tips that appear inside them. Items in this comma-separated list of selectors will be set to overflow:visible when a tip is shown inside them.'),
      '#default_value' => $config->get('allow_overflow'),
    ];
    $form['results']['embedded_content_warning'] = [
      '#title' => $this->t("Warn in Full Check that these elements need manual review"),
      '#type' => 'textfield',
      '#description' => $this->t('Provide a comma-separated list of selectors for elements with potentially complex issues, e.g.: <code>.my-embedded-feed, #my-social-link-block</code>.<br> Note that this test ignores the ignore list, so that you can specify elements where the content is ignored but the wrapper itself is flagged.'),
      '#default_value' => $config->get('embedded_content_warning'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('editoria11y.settings')
      ->set('ignore_containers', Xss::filter($form_state->getValue('ignore_containers')))
      ->set('assertiveness', $form_state->getValue('assertiveness'))
      ->set('no_load', Xss::filter($form_state->getValue('no_load')))
      ->set('content_root', Xss::filter($form_state->getValue('content_root')))
      ->set('allow_overflow', Xss::filter($form_state->getValue('allow_overflow')))
      ->set('embedded_content_warning', Xss::filter($form_state->getValue('embedded_content_warning')))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
